@@ -78,13 +78,14 @@ has merge_conf => sub {#hashref
 
 has access => sub {# object
   my $self = shift;
+  weaken $self;
   my $conf = $self->merge_conf->{'access'};
   @{$self->merge_conf->{template}{tables}}{keys %{$conf->{tables}}} = values %{$conf->{tables}}
     if $conf->{tables};
   my $class = load_class($conf);
   $class->import( @{ $conf->{import} });
   $class->new(app=>$self->app, plugin=>$self,);
-};
+}, weak => 1;
 
 has admin => sub {# object
   my $self = shift;
@@ -92,7 +93,7 @@ has admin => sub {# object
   @{$self->merge_conf->{template}{tables}}{keys %{$conf->{tables}}} = values %{$conf->{tables}}
     if $conf->{tables};
   load_class($conf)->init(%$conf, app=>$self->app, plugin=>$self,);
-};
+}, weak => 1;
 
 has oauth => sub {
   my $self = shift;
@@ -100,7 +101,7 @@ has oauth => sub {
   @{$self->merge_conf->{template}{tables}}{keys %{$conf->{tables}}} = values %{$conf->{tables}}
     if $conf->{tables};
   load_class($conf)->init(%$conf, app=>$self->app, plugin=>$self, model=>$self->model($conf->{controller}),);
-};
+}, weak => 1;
 
 has guest => sub {# object
   my $self = shift;
@@ -113,7 +114,7 @@ has guest => sub {# object
   
   my $class = load_class($conf);
   $class->new( %$conf, app=>$self->app, plugin=>$self, model=>$self->model($conf->{module}), );
-};
+}, weak => 1;
 
 has log => sub {# object
   my $self = shift;
@@ -128,7 +129,7 @@ has log => sub {# object
   my $class = load_class($conf);
   $class->new( %$conf, app=>$self->app, plugin=>$self, model=>$self->model($conf->{module}), )
     unless $conf->{disabled};
-};
+}, weak => 1;
 
 #~ has model => sub {
   #~ my $m = { map {$_ => load_class("Mojolicious::Plugin::RoutesAuthDBI::Model::$_")->new} qw(Profiles Namespaces Routes Refs Controllers Actions Roles Logins) };
@@ -357,13 +358,15 @@ sub model {
   my $class =  load_class(namespace => $ns, module=> $name)
     or die "Model module [$name] not found at namespace [$ns] or has errors";
   
+  weaken $self;
+  weaken $self->{app};
   $class->new(app=>$self->app, plugin=>$self); # синглетоны в общем
   
   #~ my $m = { map {$_ => load_class("Mojolicious::Plugin::RoutesAuthDBI::Model::$_")->new} qw(Profiles Namespaces Routes Refs Controllers Actions Roles Logins) };
   
 };
 
-our $VERSION = '0.860';
+our $VERSION = '0.861';
 
 =pod
 
@@ -379,7 +382,7 @@ Plugin makes an auth operations throught the plugin L<Mojolicious::Plugin::Authe
 
 =head1 VERSION
 
-0.860
+0.861
 
 =head1 NAME
 
